Connections Lifecycle over stages
*********************************

Connections will be reduced, optimized and calculated trough the lifecycle of a Balder session. This section shows how
Balder calculates these connection over the different stages of a Balder test session.